# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/bixo/developer/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/bixo/developer/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Bixo\\Developer\\": "packages/bixo/developer/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Bixo\Developer\Providers\DeveloperServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Developer'  => Bixo\Developer\Facades\Developer::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Bixo\\DeveloperTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Bixo\Developer\Providers\DeveloperServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Bixo\Developer\Providers\DeveloperServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Bixo\Developer\Providers\DeveloperServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/developer/{modulename}

**User**

    http://path-to-route-folder/user/developer/{modulename}

**Public**

    http://path-to-route-folder/developers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/developer/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/developer/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/developer/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/developer/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/developer/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/developer/{modulename}/{slug}
    METHOD: GET